hdx.scraper package
===================

Submodules
----------

hdx.scraper.exceloutput module
------------------------------

.. automodule:: hdx.scraper.exceloutput
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.googlesheets module
-------------------------------

.. automodule:: hdx.scraper.googlesheets
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.jsonoutput module
-----------------------------

.. automodule:: hdx.scraper.jsonoutput
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.nooutput module
---------------------------

.. automodule:: hdx.scraper.nooutput
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.readers module
--------------------------

.. automodule:: hdx.scraper.readers
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.rowparser module
----------------------------

.. automodule:: hdx.scraper.rowparser
   :members:
   :undoc-members:
   :show-inheritance:

hdx.scraper.scrapers module
---------------------------

.. automodule:: hdx.scraper.scrapers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hdx.scraper
   :members:
   :undoc-members:
   :show-inheritance:
